@@ -24,10 +24,12 @@ public class ProgressBar extends Composite {
 		initWidget(uiBinder.createAndBindUi(this));
 	}
 
-	public void update(final int percentage) {
+	public void update(int percentage) {		
+		if (percentage > 100)
+			percentage = 100;
 		if (percentage < START_PERECENTAGE || percentage > COMPLETE_PERECENTAGE) {
-			throw new IllegalArgumentException("invalid value for percentage");
-		} else { //cannot use DOM getElemById cus the second time you ipen the popup it fails		
+			throw new IllegalArgumentException("invalid value for percentage " + percentage);
+		} else { //cannot use DOM getElemById cus the second time you open the popup it fails		
 			progressBarContainer.getElement().setAttribute("style", "width: "+percentage+"%");
 			progressBarContainer.getElement().getFirstChildElement().getFirstChildElement().setInnerText(percentage+"%");
 		}
